// -*- c++ -*-
/*
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/

#if !defined __RECORDING_H
#define __RECORDING_H

#include "stringrep.h"
#include <string>
#include <ctime>
#include <iostream>

/** Represents a scheduled recording */

class Recording : public StringRep {
public:
  Recording()
    : job(-1), priority(-1), duration(0), uid(0)
  {
  }

  Recording(const std::string &type,
	    const std::string &channel,
	    bool convertToPS,
	    int priority,
	    time_t startTime,
	    unsigned duration,
	    const std::string &path,
	    uid_t uid,
	    const std::string &extra)
    : job(-1),
      type(type), channel(channel),
      convertToPS(convertToPS),
      priority(priority), startTime(startTime),
      duration(duration), path(path), 
      uid(uid),
      extra(extra)
  {
  }

  ~Recording();

  void setJob(int job) {
    this->job = job;
  }

  int getJob() const {
    return job;
  }

  std::string getType() const {
    return type;
  }

  std::string getChannel() const {
    return channel;
  }

  bool getConvertToPS() const {
    return convertToPS;
  }

  int getPriority() const {
    return priority;
  }

  time_t getStartTime() const {
    return startTime;
  }

  unsigned getDuration() const {
    return duration;
  }

  time_t getStopTime() const {
    return startTime + duration;
  }

  std::string getPath() const {
    return path;
  }

  uid_t getUid() const {
    return uid;
  }

  /** To associate extra information with the recording (useful for
      pvrs) */
  std::string getExtra() const {
    return extra;
  }

  friend std::istream &operator >> (std::istream &i, Recording &r);

protected:

  virtual std::ostream& printOn(std::ostream &) const;

private:
  int job;
  std::string type, channel;
  bool convertToPS;
  int priority; 
  time_t startTime;
  unsigned duration;
  std::string path;
  int uid;
  std::string extra;
};

#endif // __RECORDING_H
